---
layout: default
title: Overview
nav_order: 2
---

This is the overview page
https://stackoverflow.com/questions/14740705/difference-between-geojson-and-topojson
https://stackoverflow.com/questions/18900022/topojson-quantization-vs-simplification
